//
//  CanvasView.swift
//  CanvasView
//
//  Created by Valery Bashkatov on 22.08.15.
//  Copyright (c) 2015 Valery Bashkatov. All rights reserved.
//

import UIKit

/**
The `CanvasView` class makes it easy to draw the shapes inside.
*/
class CanvasView: UIView {

    // MARK: - Properties
    /**
    The paths that are be drawn.
    */
    var paths = [CanvasPath]() {
        didSet {
            // Redraw paths
            setNeedsDisplay()
        }
    }
    
    // MARK: - Initialization
    override init(frame: CGRect) {
        super.init(frame: frame)
        setup()
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        setup()
    }
    
    private func setup() {
        // Set false for default transparent background color.
        opaque = false
    }
    
    // MARK: - Drawing
    override func drawRect(rect: CGRect) {
        for path in paths {
            if path.strokeColor != nil {
                path.strokeColor!.setStroke()
                path.stroke()
            }
            
            if path.fillColor != nil {
                path.fillColor!.setFill()
                path.fill()
            }
        }
    }
}